@@ -3,7 +3,7 @@
 require 'adsf/live'
 require 'listen'
 require 'nanoc'
-require 'nanoc/cli'
+require 'nanoc/orig_cli'
 
 module Nanoc
   module Live
