@@ -66,12 +66,12 @@ module Nanoc::DataSources
 
     # See {Nanoc::DataSource#items}.
     def items
-      load_objects(content_dir_name, Nanoc::Int::Item)
+      load_objects(content_dir_name, Nanoc::Core::Item)
     end
 
     # See {Nanoc::DataSource#layouts}.
     def layouts
-      load_objects(layouts_dir_name, Nanoc::Int::Layout)
+      load_objects(layouts_dir_name, Nanoc::Core::Layout)
     end
 
     def item_changes
@@ -141,11 +141,11 @@ module Nanoc::DataSources
     def read_proto_document(content_filename, meta_filename, klass)
       is_binary = content_filename && !@site_config[:text_extensions].include?(File.extname(content_filename)[1..-1])
 
-      if is_binary && klass == Nanoc::Int::Item
+      if is_binary && klass == Nanoc::Core::Item
         meta = (meta_filename && YAML.load_file(meta_filename)) || {}
 
         ProtoDocument.new(is_binary: true, filename: content_filename, attributes: meta)
-      elsif is_binary && klass == Nanoc::Int::Layout
+      elsif is_binary && klass == Nanoc::Core::Layout
         raise Errors::BinaryLayout.new(content_filename)
       else
         parse_result = parse(content_filename, meta_filename)
@@ -261,9 +261,9 @@ module Nanoc::DataSources
       full_content_filename = content_filename && File.expand_path(content_filename)
 
       if proto_doc.binary?
-        Nanoc::Int::BinaryContent.new(full_content_filename)
+        Nanoc::Core::BinaryContent.new(full_content_filename)
       else
-        Nanoc::Int::TextualContent.new(proto_doc.content, filename: full_content_filename)
+        Nanoc::Core::TextualContent.new(proto_doc.content, filename: full_content_filename)
       end
     end
 
@@ -351,7 +351,7 @@ module Nanoc::DataSources
     # can be the content filename or the meta filename.
     def identifier_for_filename(filename)
       if config[:identifier_type] == 'full'
-        return Nanoc::Identifier.new(filename)
+        return Nanoc::Core::Identifier.new(filename)
       end
 
       regex =
@@ -360,7 +360,7 @@ module Nanoc::DataSources
         else
           allow_periods_in_identifiers? ? /\.[^\/\.]+$/ : /\.[^\/]+$/
         end
-      Nanoc::Identifier.new(filename.sub(regex, ''), type: :legacy)
+      Nanoc::Core::Identifier.new(filename.sub(regex, ''), type: :legacy)
     end
 
     # Returns the base name of filename, i.e. filename with the first or all
