@@ -12,10 +12,9 @@ module Nanoc::Extra
   Deployer = Nanoc::Deploying::Deployer
 
   # @deprecated
-  Pruner = Nanoc::Pruner
+  Pruner = Nanoc::Core::Pruner
 end
 
 require_relative 'extra/link_collector'
-require_relative 'extra/piper'
 require_relative 'extra/jruby_nokogiri_warner'
 require_relative 'extra/core_ext'
