@@ -20,3 +20,13 @@ require_relative 'rule_dsl/routing_rule_context'
 require_relative 'rule_dsl/rule'
 require_relative 'rule_dsl/compilation_rule'
 require_relative 'rule_dsl/routing_rule'
+
+Nanoc::Core::Checksummer.define_behavior(
+  Nanoc::RuleDSL::CompilationRuleContext,
+  Nanoc::Core::Checksummer::RuleContextUpdateBehavior,
+)
+
+Nanoc::Core::Checksummer.define_behavior(
+  Nanoc::RuleDSL::RulesCollection,
+  Nanoc::Core::Checksummer::DataUpdateBehavior,
+)
