@@ -2,12 +2,12 @@
 
 module Nanoc::RuleDSL
   class CompilationRule < Rule
-    include Nanoc::Int::ContractsSupport
+    include Nanoc::Core::ContractsSupport
 
-    contract Nanoc::Int::ItemRep, C::KeywordArgs[
-      site: Nanoc::Int::Site,
+    contract Nanoc::Core::ItemRep, C::KeywordArgs[
+      site: Nanoc::Core::Site,
       recorder: Nanoc::RuleDSL::ActionRecorder,
-      view_context: Nanoc::ViewContextForPreCompilation,
+      view_context: Nanoc::Core::ViewContextForPreCompilation,
     ] => C::Any
     def apply_to(rep, site:, recorder:, view_context:)
       context = Nanoc::RuleDSL::CompilationRuleContext.new(
