@@ -101,13 +101,13 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     File.open('foo/stuff.dat', 'w') { |io| io.write('random binary data') }
 
     # Load
-    items = data_source.send(:load_objects, 'foo', Nanoc::Int::Item)
+    items = data_source.send(:load_objects, 'foo', Nanoc::Core::Item)
 
     # Check
     assert_equal 1, items.size
     assert items[0].content.binary?
     assert_equal "#{Dir.getwd}/foo/stuff.dat", items[0].content.filename
-    assert_equal Nanoc::Int::BinaryContent, items[0].content.class
+    assert_equal Nanoc::Core::BinaryContent, items[0].content.class
   end
 
   def test_load_layouts_with_nil_dir_name
@@ -135,7 +135,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
 
     # Load
     assert_raises(Nanoc::DataSources::Filesystem::Errors::BinaryLayout) do
-      data_source.send(:load_objects, 'foo', Nanoc::Int::Layout)
+      data_source.send(:load_objects, 'foo', Nanoc::Core::Layout)
     end
   end
 
@@ -468,7 +468,7 @@ class Nanoc::DataSources::FilesystemTest < Nanoc::TestCase
     File.write('foo/donkey.jpeg', 'data')
     File.write('foo/donkey.yaml', "---\nalt: Donkey\n")
 
-    objects = data_source.send(:load_objects, 'foo', Nanoc::Int::Item)
+    objects = data_source.send(:load_objects, 'foo', Nanoc::Core::Item)
     assert_equal 1, objects.size
     assert_equal '/donkey.jpeg', objects.first.identifier.to_s
   end
