@@ -40,7 +40,7 @@ class Nanoc::Filters::PandocTest < Nanoc::TestCase
       # Run filter
       args = [:s, { f: :markdown, to: :html }, 'wrap=none', :toc]
       result = filter.setup_and_run("# Heading\n", args: args)
-      assert_match '<nav id="TOC">', result
+      assert_match '<nav id="TOC"', result
       assert_match(%r{<h1 id=\"heading\">Heading</h1>\s*}, result)
     end
   end
