@@ -9,8 +9,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -35,8 +35,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -61,8 +61,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -87,8 +87,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -127,8 +127,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -165,8 +165,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -191,8 +191,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -217,8 +217,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -243,8 +243,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -269,8 +269,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -295,8 +295,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -321,8 +321,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -347,8 +347,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -373,8 +373,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -397,8 +397,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -433,8 +433,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -459,8 +459,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -485,8 +485,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -511,8 +511,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -540,8 +540,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -566,8 +566,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -593,8 +593,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/bar/baz',
@@ -626,8 +626,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/bar/baz',
@@ -658,8 +658,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/bar/baz',
@@ -695,8 +695,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/bar/baz',
@@ -737,8 +737,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/bar/baz',
@@ -772,8 +772,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/baz',
@@ -789,7 +789,6 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 <!--[if lt IE 9]>
     <script src="/js/lib/html5shiv.js"></script>
 <![endif]-->
-
 )
 
       actual_content = filter.setup_and_run(raw_content.freeze, type: :xhtml)
@@ -806,8 +805,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/baz',
@@ -822,7 +821,6 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 <!--[if lt IE 9]>
     <script src="/js/lib/html5shiv.js"></script>
 <![endif]-->
-
 )
 
       # Test
@@ -837,8 +835,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
     # Mock item
     filter.instance_eval do
-      @item_rep = Nanoc::Int::ItemRep.new(
-        Nanoc::Int::Item.new(
+      @item_rep = Nanoc::Core::ItemRep.new(
+        Nanoc::Core::Item.new(
           'content',
           {},
           '/foo/bar/baz',
@@ -864,8 +862,8 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
 
       # Mock item
       filter.instance_eval do
-        @item_rep = Nanoc::Int::ItemRep.new(
-          Nanoc::Int::Item.new(
+        @item_rep = Nanoc::Core::ItemRep.new(
+          Nanoc::Core::Item.new(
             'content',
             {},
             '/foo/baz',
